@@ -3,8 +3,8 @@
 ;; Copyright (C) 2021-2022 Tony Aldon
 
 ;; Author: Tony Aldon <tony@tonyaldon.com>
-;; Package-Version: 1.1
-;; Package-Revision: fa52cf0144f8
+;; Package-Version: 20250824.1102
+;; Package-Revision: 0960d56c5a28
 ;; Package-Requires: ((emacs "28.1") (jack "1.0") (htmlize "1.57"))
 ;; Keywords: hypermedia, outlines
 ;; Homepage: https://github.com/tonyaldon/one.el
@@ -362,7 +362,7 @@ INFO is a plist holding contextual information."
     (or custom-type-link
         (and
          (string-match one-ox-link-image-extensions path)
-         (format "<p><img src=\"%s\" alt=\"%s\" /></p>"
+         (format "<img src=\"%s\" alt=\"%s\" />"
                  href (or (org-string-nw-p desc) href)) )
         (format "<a href=\"%s\">%s</a>"
                 href (or (org-string-nw-p desc) href)))))
@@ -1201,20 +1201,20 @@ img {
   display: flex;
   margin-left: auto;
   margin-right: auto;
-  max-width: 1140px;
+  max-width: 950px;
   width: 100%;
   padding: 1em 16px;
 }
 
 #sidebar {
-  border-right: 2px solid #31424a;
+  position: fixed;
   top: 4.5rem;
-  position: sticky;
-  padding-top: 2.2em;
-  padding-bottom: 6em;
+  bottom: 1em;
+  left: calc((100vw - 950px)/2);
   width: 250px;
-  max-height: 100vh;
   overflow-y: auto;
+  padding: 2.2em 0 6em;
+  border-right: 2px solid #31424a;
 }
 
 #sidebar a {
@@ -1240,6 +1240,7 @@ img {
 }
 
 article {
+  margin-left: 250px;
   padding: 0 1.5em;
   max-width: 640px;
   width: 100%;
@@ -1301,7 +1302,7 @@ article {
   z-index: 2;
 }
 
-@media (max-width: 840px) {
+@media (max-width: 950px) {
   #hamburger {
     display: block;
   }
@@ -1315,7 +1316,8 @@ article {
     justify-content: left;
   }
   article {
-    padding: 0;
+    margin-left: 0;
+    padding: 0 1em;
   }
 }
 "
